import { TextField } from "@mui/material";
import { useQuery } from "@tanstack/react-query";
import { ChangeEventHandler, useState } from "react";
import { DropdownFilter } from "../components/dropdown-filter";
import { VenueGrid } from "../components/venue-grid";
import { API } from "../lib/api";
import { Environment } from "../lib/environment";
import { TCategory, TTag, TVenue } from "../lib/types";

export function Index() {
    const [nameTextFilter, setNameTextFilter] = useState<string | null>(null);
    const [filteredTags, setFilteredTags] = useState<TTag[]>([]);
    const [filteredCategories, setFilteredCategories] = useState<TCategory[]>([]);

    const api = new API(Environment.BaseAPIUrl);

    const { data: venueData } = useQuery<TVenue[], Error>(["venues", filteredCategories, filteredTags, nameTextFilter], () => api.getVenues({nameFilter: nameTextFilter, categories: filteredCategories, tags: filteredTags}));

    const { data: categoryData } = useQuery<TCategory[], Error>(["categories"], api.getCategories);

    const { data: tagData } = useQuery<TTag[], Error>(["tags"], api.getTags);

    const handleSearchChange = (event: any) => {
        const { value } = event.target;

        if (value && value.length === 0) {
            setNameTextFilter(null);
        }

        setNameTextFilter(value as string);
    }

    return(
        <>
            <h1>Leeds Beer Quest</h1>
            <div style={{ display: "flex", justifyContent: "space-around" }}>
                <TextField label={"Name"} variant="outlined" onChange={handleSearchChange} />
                <DropdownFilter filters={tagData ?? []} setSelectedFilters={setFilteredTags} prefillText={"Tags"} />
                <DropdownFilter filters={categoryData ?? []} setSelectedFilters={setFilteredCategories} prefillText={"Categories"} />
            </div>
            <VenueGrid venueData={venueData ?? []} />
        </>
    );
};